@@ -9,7 +9,6 @@ from dialogs.interpretation.statements_builder import *
 from dialogs.sentence import *
 from dialogs.sentence_factory import SentenceFactory
 
-from pyoro import OroServerError
 from dialogs.resources_manager import ResourcePool
 from dialogs.dialog_exceptions import DialogError, GrammaticalError
 
@@ -209,7 +208,7 @@ class QuestionHandler:
         
         if find_id:
             try:
-                sit_id = ResourcePool().ontology_server.find('?event', statements)
+                sit_id = ResourcePool().ontology_server.find(['?event'], statements)
             except AttributeError: #the ontology server is not started of doesn't know the method
                 pass
                 
