@@ -3,7 +3,7 @@ logger = logging.getLogger("dialogs")
 
 import random
 
-from pyoro import OroServerError
+from kb import KbError
 
 from dialogs.resources_manager import ResourcePool
 from dialogs.dialog_exceptions import DialogError, GrammaticalError
@@ -338,7 +338,7 @@ class NominalGroupStatementBuilder:
                 onto_id = ResourcePool().ontology_server.lookupForAgent(self._current_speaker, noun)
             except AttributeError: #the ontology server is not started of doesn't know the method
                 pass
-            except OroServerError: #The agent does not exist in the ontology
+            except KbError: #The agent does not exist in the ontology
                 pass
             
             instance_id = None
@@ -747,7 +747,7 @@ class VerbalGroupStatementBuilder:
                 else:
                     self._statements.append(sit_id + " rdf:type " + verb.capitalize())
                     self._statements.append(sit_id + " performedBy " + subject_id)
-                    if not self._process_on_question:
+                    if not self._process_on_question and self._process_on_resolved_sentence:
                         # If I'm not processing a question, add a label
                         # to this action
                         self._statements.append(sit_id + " rdfs:label \"" + \
